aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--lv2/lv2plug.in/ns/ext/atom/atom-helpers.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/lv2/lv2plug.in/ns/ext/atom/atom-helpers.h b/lv2/lv2plug.in/ns/ext/atom/atom-helpers.h
index 3bfad57..e6ecd9c 100644
--- a/lv2/lv2plug.in/ns/ext/atom/atom-helpers.h
+++ b/lv2/lv2plug.in/ns/ext/atom/atom-helpers.h
@@ -173,8 +173,8 @@ lv2_tuple_iter_get(LV2_Atom_Tuple_Iter i)
This macro is used similarly to a for loop (which it expands to), e.g.:
@code
LV2_TUPLE_FOREACH(tuple, i) {
- LV2_Atom_Property* prop = lv2_tuple_iter_get(i);
- // Do something with prop here...
+ LV2_Atom* elem = lv2_tuple_iter_get(i);
+ // Do something with elem here...
}
@endcode
*/
@@ -239,7 +239,7 @@ lv2_object_iter_get(LV2_Atom_Object_Iter i)
This macro is used similarly to a for loop (which it expands to), e.g.:
@code
LV2_OBJECT_FOREACH(object, i) {
- LV2_Atom_Property* prop = lv2_object_iter_get(i);
+ LV2_Atom_Property_Body* prop = lv2_object_iter_get(i);
// Do something with prop here...
}
@endcode